betty.extension.wikipedia.config module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.wikipedia.config module

Provide configuration for the Wikipedia extension.

class betty.extension.wikipedia.config.WikipediaConfiguration

  Bases: `Configuration`

  Provides configuration for the `betty.extension.wikipedia.Wikipedia` extension.

  __init__()
  dump() → bool | int | float | str | None | MutableSequence[bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]] | MutableMapping[str, bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]] | type[Void]

    Dump this instance to a portable format.

  load(dump: bool | int | float | str | None | MutableSequence[bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]] | MutableMapping[str, bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]]) → None

    Load dumped configuration.

    Raises:

      betty.assertion.error.AssertionFailed – Raised if the dump contains invalid configuration.

  property populate_images: bool

    Whether to populate entities with Wikimedia images after loading ancestries.

  update(other: Self) → None

    Update this configuration with the values from `other`.